Wireless Charging & Backup Battery | Duracell Powermat | Duracell Powermat
Description: Duracell Powermat wireless charging pads, battery cases, and backup battery power for iPhone 6, iPhone 5, iPad, Samsung, Android and tablets. Power up!
Keywords: duracell, powermat, wireless charging, charging pad, backup battery, battery case, iphone cas

# Duracell Powermat

- ## Long Live Your iPhone

  Take charge of your device and ensure you never miss a call, text, or memory.

- ## Live Fully Charged

  Now available at Starbucks in San Francisco / Bay Area. Find locations here.

- ## Style Comes Calling

  Be chic and powerful with this stunning Michael Kors designed collection, exclusively sold
  at Michael Kors.

shop top brands

Recommended products Recently viewed

Back to Top

#### Relax, It's Charging

Have the power to do more with your phone this year. Stay Charged, Anytime, Anywhere with Duracell Powermat.